package org.fuseri.modulelanguageschool.lecture;

import jakarta.persistence.Column;
import jakarta.persistence.Entity;
import jakarta.persistence.ManyToMany;
import jakarta.persistence.ManyToOne;
import lombok.*;
import org.fuseri.modulelanguageschool.common.DomainObject;
import org.fuseri.modulelanguageschool.course.Course;
import org.fuseri.modulelanguageschool.user.User;

import java.time.LocalDateTime;
import java.util.List;

/**
 * This class represents a lecture entity in the domain model.
 */
@Getter
@Setter
@Builder
@NoArgsConstructor
@AllArgsConstructor
@Entity
public class Lecture extends DomainObject {

    /**
     * The start time of the lecture.
     */
    @Column(name = "lecture_from")
    private LocalDateTime from;

    /**
     * The end time of the lecture.
     */
    @Column(name = "lecture_to")
    private LocalDateTime to;

    /**
     * The course that the lecture is associated with.
     */
    @ManyToOne
    private Course course;

    /**
     * The list of users attending the lecture.
     */
    @ManyToMany
    private List<User> user;
}
